@@ -10,12 +10,10 @@ class NN(tf.keras.Model):
 
     def __init__(self):
         super(NN, self).__init__()
-        self._inputs = None
-        self._targets = None
-        self._auxiliary_vars = None
-
+        self.training = True
         self.regularizer = None
-
+        self._inputs = None
+        self._auxiliary_vars = None
         self._input_transform = None
         self._output_transform = None
 
@@ -28,15 +26,6 @@ class NN(tf.keras.Model):
     def inputs(self, value):
         self._inputs = value
 
-    @property
-    def targets(self):
-        """Return the targets of the net outputs (Tensors)."""
-        return self._targets
-
-    @targets.setter
-    def targets(self, value):
-        self._targets = value
-
     @property
     def auxiliary_vars(self):
         """Tensors: Any additional variables needed."""
